:mod:`ping` --- Share chain status
==================================

.. classoverview::
   :class:`neo3.network.payloads.ping.PingPayload`

A minimalistic class used by the :const:`~neo3.network.message.MessageType.PING` and :const:`~neo3.network.message.MessageType.PONG` message types to share and/or request node chain status.

.. autoclass:: neo3.network.payloads.ping.PingPayload
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
